var Receiver = {
    client: null,
    nowRetryCount: 0,
    allRetryCount: 3,
    receiveTypes: {
        NOTIFICATION_SYSTEM: 0,
        NOTIFICATION_SHOP_AUDIT: 1,
        NOTIFICATION_TIMELINE_STAR: 2,
        NOTIFICATION_TIMELINE_COMMENT: 3,
        NOTIFICATION_FORUM_ARTICLE_COMMENT: 4,
        NOTIFICATION_FORUM_ARTICLE_COMMENT_REPLY: 5,
    },
    init: function() {
        var _this = this;
        if (!_this.client) {
            _this.client = api.require("ajpush");
        }
        if (api.systemType.toUpperCase() == 'ANDROID') {
            _this.client.init(function(ret) {
                if (ret && ret.status) {
                    _this.nowRetryCount = 0;
                    _this.bindUserId();
                } else {
                    if (_this.nowRetryCount < _this.allRetryCount) {
                        _this.nowRetryCount++;
                        setTimeout(function() {
                            _this.init();
                        }, _this.nowRetryCount * 2000);
                    }
                }
            });
        } else {
            _this.bindUserId();
        }
    },
    bindUserId: function() {
        var user_id = $k.getLoginUser().id;
        var _this = this;
        _this.client.bindAliasAndTags({
            alias: user_id
        }, function(ret) {
            var statusCode = ret.statusCode;
            if (ret && ret.statusCode == 0) {
                _this.nowRetryCount = 0;
                _this.setReceiveListener();
            } else {
                if (_this.nowRetryCount < _this.allRetryCount) {
                    _this.nowRetryCount++;
                    setTimeout(function() {
                        _this.bindUserId();
                    }, _this.nowRetryCount * 2000);
                }
            }
        });
    },
    setReceiveListener: function() {
        if (api.systemType.toUpperCase() == 'ANDROID') {
            this.setAndroidListener();
        } else {
            this.setIosListener();
        }
    },
    setAndroidListener: function() {
        var _this = this;
        api.addEventListener({
            name: 'appintent'
        }, function(ret, err) {
            if (ret && ret.appParam.ajpush) {
                _this.calcReceived(ret.appParam.ajpush.extra);
            }
        });
    },
    setIosListener: function() {
        var _this = this;
        api.addEventListener({
            name: 'noticeclicked'
        }, function(ret, err) {
            if (ret && ret.value) {
                _this.calcReceived(ret.value.ajpush.extra);
            }
        })
    },
    calcReceived: function(extra) {
        var type = parseInt(extra.type);
        switch (type) {
            case this.receiveTypes.NOTIFICATION_SHOP_AUDIT:
                // 店铺审核结果通知,点击通知的时候刷新个人中心,跳转到我的店铺界面
                $k.sendEvent(eventName.refreshUserCenter);
                $k.openWin("myShop_win", "shop/myShop_win");
                break;
            case this.receiveTypes.NOTIFICATION_TIMELINE_STAR:
                // 茶圈点赞通知,点击通知的时候刷新茶圈列表,跳转到社交个人中心
            case this.receiveTypes.NOTIFICATION_TIMELINE_COMMENT:
                // 茶圈评论通知,点击通知的时候刷新茶圈列表,跳转到社交个人中心
                $k.sendEvent(eventName.reloadTimelineList);
                $k.openWin('socialMyCenter_win', 'user/socialMyCenter_win');
                break;
            case this.receiveTypes.NOTIFICATION_FORUM_ARTICLE_COMMENT:
                // 社区评论通知,点击通知的时候刷新社区列表,跳转到文章详情页
            case this.receiveTypes.NOTIFICATION_FORUM_ARTICLE_COMMENT_REPLY:
                // 社区回复通知,点击通知的时候刷新社区列表,跳转到文章详情页
                $k.sendEvent(eventName.reloadArticleList);
                $k.openWin("forumDesc_win", "forum/forumDesc_win", {
                    articleId: extra.id
                });
                break;
            default:
        }
    }
};
