/**
 * websocket工具类
 */
var wsClient;
var imClient = {
    path: 'ws://im.hlbshop.com:12580',
    CODE_ERROR: 500,
    CODE_PING: 0,
    CODE_BIND: 1,
    CODE_MESSAGE: 2,
    CODE_RESULT_SUCCESS: 3,
    CODE_RESULT_ERROR: 4,
    CODE_FRIEND_REQUEST: 5,
    CODE_FRIEND_REQUEST_SUCCESS: 6,
    CODE_FRIEND_REQUEST_FAILED: 7,
    CODE_ADD_FRIEND_ACCEPT: 8,
    CODE_ADD_FRIEND_REJECT: 9,
    is_connected: false,
    app_status: 1, // 应用状态:1前台,0后台
    start: function() {
        var _this = this;
        if (!wsClient) {
            wsClient = api.require('webSocket');
        }
        wsClient.close(function(ret, err) {
            wsClient.open({
                url: _this.path,
                pingInterval: 59,
                pingData: '{"code":' + _this.CODE_PING + '}',
            }, function(ret, err) {
                if (ret && ret.status) {
                    _this.is_connected = true;
                    _this.addEventListener();
                } else {
                    setTimeout(_this.start, 5000); // 5s后尝试重新连接
                }
            });
        });
    },
    addEventListener: function() {
        var _this = this;
        wsClient.addEventListener(function(ret, err) {
            if (!ret || !ret.status) {
                return;
            }
            if (ret.evenType == 'ReturnData') { // 收到消息
                _this.onMessage(ret.data);
            } else if (ret.evenType == 'Connected') { // 连接成功
                _this.onConnected(ret);
            } else if (ret.evenType == 'Closed') { // 关系连接
                _this.onClosed(ret);
            }
        });
    },
    onMessage: function(data) {
        // console.log("received==>" + JSON.stringify(data));
        data = JSON.parse(data);
        switch (data.code) {
            case imClient.CODE_BIND:
                // 绑定失败则尝试重新绑定
                if (!data.content) {
                    this.doBind();
                }
                // console.log(JSON.stringify(data));
                break;
            case imClient.CODE_MESSAGE:
                // 刷新消息列表
                $k.sendEvent(eventName.reloadChatList);
                // 添加聊天记录消息项
                $k.sendEvent(eventName.addMessageItem, data);
                // 通知有新消息
                if (this.app_status > 0) {
                    api.notification();
                } else {
                    api.notification({
                        notify: {
                            title: '新消息',
                            content: data.from_name + '发来一条消息'
                        }
                    });
                }
                break;
            case imClient.CODE_FRIEND_REQUEST:
                // 请求添加好友通知,如果在前台则提示即可
                // 不在前台则设置通知栏
                if (this.app_status > 0) {
                    api.notification();
                } else {
                    api.notification({
                        notify: {
                            title: '新朋友',
                            content: data.content
                        }
                    });
                }
                // 刷新好友添加请求信息和请求列表
                $k.sendEvent(eventName.reloadAddFriendList);
                $k.sendEvent(eventName.reloadAddFriendListCount);
                break;
            case imClient.CODE_FRIEND_REQUEST_SUCCESS: // 添加好友请求成功结果通知
            case imClient.CODE_FRIEND_REQUEST_FAILED: // 添加好友请求失败结果通知
                api.toast({
                    msg: data.content,
                    duration: 2000,
                    location: 'bottom',
                    global: true
                });
                break;
            case imClient.CODE_ADD_FRIEND_ACCEPT: // 好友请求接受通知
                // 请求添加好友通知,如果在前台则提示即可
                // 不在前台则设置通知栏
                if (this.app_status > 0) {
                    api.notification();
                } else {
                    api.notification({
                        notify: {
                            title: '新消息',
                            content: data.content
                        }
                    });
                }
                // 刷新好友列表
                $k.sendEvent(eventName.reloadTimelineList);
                break;
            case imClient.CODE_ADD_FRIEND_REJECT: // 好友请求拒绝通知
                // 请求添加好友通知,如果在前台则提示即可
                // 不在前台则设置通知栏
                if (this.app_status > 0) {
                    api.notification();
                } else {
                    api.notification({
                        notify: {
                            title: '新消息',
                            content: data.content
                        }
                    });
                }
                break;
            default:
                // console.log(JSON.stringify(data));
        }
    },
    onConnected: function(ret) {
        // console.log('Websocket Connected');
        // 发送绑定请求
        this.doBind();
    },
    onClosed: function(ret) {
        // console.log('Websocket Closed');
    },
    doBind: function() {
        var uid = $k.getLoginUser().id;
        this.sendMessage({
            "code": this.CODE_BIND,
            "from_id": uid,
        });
    },
    sendMessage: function(data) {
        if (!wsClient) {
            wsClient = api.require('webSocket');
        }
        wsClient.send({
            data: JSON.stringify(data)
        }, function(ret, err) {
            // console.log('sendResult==>' + JSON.stringify(ret));
        });
    },
    doClose: function() {
        if (!wsClient) {
            wsClient = api.require('webSocket');
        }
        wsClient.close(function(ret, err) {
            // console.log(JSON.stringify(ret) + "  " + JSON.stringify(err));
        });
    }
};
